import React, { useEffect, useState } from 'react'
import { Route } from 'react-router-dom'

import FrontPage from 'routes/sponsor/frontpage'
import GuestInfo from 'routes/sponsor/guestInfo'
import GuestRoleInfo from 'routes/sponsor/guestRoleInfo'
import { FetchedGuest, Guest } from 'interfaces'
import { parseRole } from 'utils'

function Sponsor() {
  const [guests, setGuests] = useState<Guest[]>([])

  const getGuestsInfo = async () => {
    try {
      const response = await fetch('/api/ui/v1/guests/?format=json')
      const jsonResponse = await response.json()
      if (response.ok) {
        const persons = await jsonResponse.persons
        setGuests(
          persons.map(
            (person: FetchedGuest): Guest => ({
              pid: person.pid,
              first: person.first,
              last: person.last,
              email: person.email,
              mobile: person.mobile,
              fnr: person.fnr,
              active: person.active,
              roles: person.roles.map((role) => parseRole(role)),
              registered: person.registered,
              verified: person.verified,
            })
          )
        )
      }
    } catch (error) {
      setGuests([])
    }
  }

  useEffect(() => {
    getGuestsInfo()
  }, [])

  return (
    <>
      <Route path="/sponsor/guest/:pid/roles/:id">
        <GuestRoleInfo guests={guests} />
      </Route>
      <Route exact path="/sponsor/guest/:pid">
        <GuestInfo />
      </Route>
      <Route exact path="/sponsor">
        <FrontPage guests={guests} />
      </Route>
    </>
  )
}

export default Sponsor
